# Smeagol 

Smeagol is a simple Python wiki designed to be compatible with Git wiki 
repos.

## Initial Release and Security

This initial release (version 0.1.0) is not fully functional. There are several 
known bugs and security issues that need to be addressed before version 1.0. 
This initial release is intended to be run in controlled or isolated 
environments. 

## Install

1. Clone this repo: `https://github.com/josh-kaplan/smeagol.git`
2. Run `cd smeagol && python setup.py install`

## Usage

1. Enter a directory containing a Git-compatible wiki.
2. Run `smeagol serve`

